@@ -23,6 +23,24 @@ def iterative_beam_search(branching_scheme, **parameters):
     verbose = parameters.get(
             "verbose", True)
 
+    if verbose:
+        print("======================================")
+        print("          Tree Search Solver          ")
+        print("======================================")
+        print()
+        print("Algorithm")
+        print("---------")
+        print("Iterative Beam Search")
+        print()
+        print("Parameters")
+        print("----------")
+        print(f"Minimum size of the queue:  {minimum_size_of_the_queue}")
+        print(f"Maximum size of the queue:  {maximum_size_of_the_queue}")
+        print(f"Maximum number of nodes:    {maximum_number_of_nodes}")
+        print(f"Growth factor:              {growth_factor}")
+        print(f"Maximum pool size:          {maximum_pool_size}")
+        print(f"Time limit:                 {time_limit}")
+
     # Setup structures.
     solution_pool = ts.SolutionPool(branching_scheme, maximum_pool_size)
     q = SortedList()
@@ -127,6 +145,9 @@ def iterative_beam_search(branching_scheme, **parameters):
 
     # Final display.
     solution_pool.display_end(start, verbose)
+    if verbose:
+        print(f"Number of nodes:             {number_of_nodes}")
+        print(f"Maximum size of the queue:   {queue_size}")
 
     end = time.time()
 
